@@ -1,21 +1,7 @@
 /*
- *  soldevice.cpp
+ *  SPDX-FileCopyrightText: 2009 David Hubner <hubnerd@ntlworld.com>
  *
- *  Copyright (C) 2009 David Hubner <hubnerd@ntlworld.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -68,7 +54,7 @@ SolDevice::SolDevice(QTreeWidgetItem *parent, const Solid::Device &device)
     setDefaultDeviceToolTip();
 }
 
-//Sets
+// Sets
 
 void SolDevice::setDefaultListing(const Solid::DeviceInterface::Type &type)
 {
@@ -81,8 +67,7 @@ void SolDevice::setDefaultDeviceText()
 
     if (deviceSet) {
         ddtString = tiedDevice.product();
-        if (tiedDevice.isDeviceInterface(Solid::DeviceInterface::StorageVolume)
-            || tiedDevice.isDeviceInterface(Solid::DeviceInterface::Battery)) {
+        if (tiedDevice.isDeviceInterface(Solid::DeviceInterface::StorageVolume) || tiedDevice.isDeviceInterface(Solid::DeviceInterface::Battery)) {
             QString label = SolDevice::udi().section(QStringLiteral("/"), -1, -1);
             if (!label.isEmpty()) {
                 ddtString = label;
@@ -162,24 +147,24 @@ bool SolDevice::isDeviceSet()
     return deviceSet;
 }
 
-bool SolDevice::operator< ( const QTreeWidgetItem & other ) const
+bool SolDevice::operator<(const QTreeWidgetItem &other) const
 {
-    const SolDevice * otherDevice = dynamic_cast<const SolDevice*>(&other);
+    const SolDevice *otherDevice = dynamic_cast<const SolDevice *>(&other);
     if (otherDevice) {
         if (deviceType() != otherDevice->deviceType()) {
             return deviceType() < otherDevice->deviceType();
         }
         switch (deviceType()) {
         case Solid::DeviceInterface::Processor: {
-                const Solid::Processor *left = tiedDevice.as<const Solid::Processor>();
-                const Solid::Processor *right = otherDevice->tiedDevice.as<const Solid::Processor>();
-                // Processors are sorted in ascending order, so this is reversed
-                return left->number() > right->number();
-            }
+            const Solid::Processor *left = tiedDevice.as<const Solid::Processor>();
+            const Solid::Processor *right = otherDevice->tiedDevice.as<const Solid::Processor>();
+            // Processors are sorted in ascending order, so this is reversed
+            return left->number() > right->number();
+        }
         case Solid::DeviceInterface::StorageVolume: {
-                // Storage volumes are sorted in ascending order (i.e. sda, sda1, sda2...)
-                return text(0) > other.text(0);
-            }
+            // Storage volumes are sorted in ascending order (i.e. sda, sda1, sda2...)
+            return text(0) > other.text(0);
+        }
         default:
             break;
         }
